==> libktorrent-1.0.5-3.tar.xz: libktorrent-1.0.5-3/src/peer/peerprotocolextension.cpp <==
/***************************************************************************
 *   Copyright (C) 2009 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#include <stdio.h>
#include "peerprotocolextension.h"
#include "packetwriter.h"
#include "peer.h"

namespace bt
{
	
	PeerProtocolExtension::PeerProtocolExtension(Uint32 id, Peer* peer) : id(id),peer(peer)
	{
	}


	PeerProtocolExtension::~PeerProtocolExtension()
	{
	}

	void PeerProtocolExtension::sendPacket(const QByteArray& data)
	{
		peer->getPacketWriter().sendExtProtMsg(id,data);
	}

	void PeerProtocolExtension::update()
	{
	}

	void PeerProtocolExtension::changeID(Uint32 id)
	{
		this->id = id;
	}

}

==> libktorrent_2.2.0.orig.tar.xz: libktorrent-2.2.0/src/peer/peerprotocolextension.cpp <==
/***************************************************************************
 *   Copyright (C) 2009 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#include "peerprotocolextension.h"
#include <stdio.h>
#include "peer.h"

namespace bt
{
	
	PeerProtocolExtension::PeerProtocolExtension(Uint32 id, Peer* peer) : id(id),peer(peer)
	{
	}


	PeerProtocolExtension::~PeerProtocolExtension()
	{
	}

	void PeerProtocolExtension::sendPacket(const QByteArray& data)
	{
		peer->sendExtProtMsg(id,data);
	}

	void PeerProtocolExtension::update()
	{
	}

	void PeerProtocolExtension::changeID(Uint32 id)
	{
		this->id = id;
	}

}
